@@ -46,7 +46,6 @@ class ContextFilter(logging_module.Filter):
 from whatap.conf.configure import Configure as conf
 
 CONFIG_FILE_NAME = 'whatap.conf'
-PLUGIN_FILE_NAME = 'plugin.json'
 LOG_FILE_NAME = 'whatap-hook.log'
 
 
@@ -130,7 +129,6 @@ def write_file(home, file_name, value):
         f.write(value)
         f.close()
     except Exception as e:
-        print(e)
         print('WHATAP: WHATAP HOME ERROR.')
         print(
             'WHATAP: Try to execute command. \n  {}'.format(
@@ -219,23 +217,6 @@ def config(home):
         from whatap.trace import PacketEnum, UdpSession
         PacketEnum.PORT = int(conf.net_udp_port)
         
-        plugin_file = os.path.join(os.environ[home], PLUGIN_FILE_NAME)
-        if conf.plugin and not os.path.exists(plugin_file):
-            content = open(
-                os.path.join(os.path.dirname(__file__),
-                             PLUGIN_FILE_NAME),
-                'r+').read()
-            try:
-                os.mknod(plugin_file)
-                new = open(plugin_file, 'w+')
-                new.write(content)
-                new.close()
-            except Exception as e:
-                logging.debug(e, extra={'id': 'PLUGIN FILE ERROR'})
-                logging.debug(
-                    'WHATAP: Try to execute command. \n  {}'.format(
-                        '`sudo chmod -R 777 $WHATAP_HOME`'))
-        
         hooks(home)
 
 
@@ -261,31 +242,29 @@ def hooks(home):
         logging.debug(e, extra={'id': 'MODULE ERROR'})
     finally:
         try:
-            plugin_file = os.path.join(os.environ.get(home, ''),
-                                       'plugin.json')
-            if conf.plugin and os.path.exists(plugin_file):
+            if conf.hook_method_patterns:
                 from whatap.trace.mod.plugin import instrument_plugin
+            
+                patterns = conf.hook_method_patterns.split(',')
+                for pattern in patterns:
+                    pattern=pattern.strip()
                 
-                with open(plugin_file, 'r+') as data_file:
-                    PLUGIN.update(json.load(data_file))
-                    delete_key = None
-                    for key, value in PLUGIN.items():
-                        if key.startswith("["):
-                            delete_key = key
-                        else:
-                            DEFINICATION["plugin"].append(
-                                (key, 'instrument_plugin'))
+                    module_name, class_def = pattern.split(':')
+                    if not PLUGIN.get(module_name):
+                        PLUGIN[module_name] = []
+                    PLUGIN[module_name].append(class_def)
                     
-                    del PLUGIN[delete_key]
-                
-                key = 'plugin'
-                for value in DEFINICATION[key]:
-                    IMPORT_HOOKS[value[0]] = {'def': value[1],
-                                              'module': '{0}.{1}.{2}.{3}'.format(
-                                                  'whatap',
-                                                  'trace',
-                                                  'mod',
-                                                  key)}
+                    DEFINICATION["plugin"].append(
+                        (module_name, 'instrument_plugin'))
+                    
+                    key = 'plugin'
+                    for value in DEFINICATION[key]:
+                        IMPORT_HOOKS[value[0]] = {'def': value[1],
+                                                  'module': '{0}.{1}.{2}.{3}'.format(
+                                                      'whatap',
+                                                      'trace',
+                                                      'mod',
+                                                      key)}
         
         except Exception as e:
             logging.debug(e, extra={'id': 'PLUGIN ERROR'})
