@@ -1,12 +1,14 @@
 Configuration = {
     "dev": False,
-    "plugin": False,
     "net_udp_port": "6600",
     "web_static_content_extensions": "js, htm, html, gif, png, jpg, css, swf, ico",
     "trace_auto_normalize_enabled": True,
     "trace_user_enabled": True,
     "trace_user_using_ip": True,
     "profile_dbc_close": False,
+    "profile_http_header_enabled": False,
+    
+    "hook_method_patterns": "",
     
     "mtid": 0,
     "httpc_checked": True,
