@@ -117,14 +117,15 @@ def interceptor(rn_environ, *args, **kwargs):
         interceptor_error(status_code, errors)
     
     if conf.profile_http_header_enabled:
+        keys = []
+        for key, value in environ.items():
+            if key.startswith('HTTP_'):
+                keys.append(key)
+        keys.sort()
+        
         text = ''
-        items = ['host', 'connection','cache_control', 'user_agent',
-                'upgrade_insecure_requests',
-                'accept', 'accept_encoding', 'accept_language',
-                'cookie']
-        for key in items:
-            if environ.get('HTTP_{}'.format(key.upper())):
-                text += '{}={}\n'.format(key, environ.get('HTTP_{}'.format(key.upper())))
+        for key in keys:
+            text += '{}={}\n'.format(key.split('HTTP_')[1].lower(), environ[key])
 
         datas = [' ', 'HTTP-HEADERS', text]
         ctx.start_time = DateUtil.nowSystem()
