@@ -1,7 +1,7 @@
 import traceback
 
 from whatap.trace import UdpSession, PacketTypeEnum
-from whatap.trace.mod.application_wsgi import transfer, inter_tx_trace_auto_on
+from whatap.trace.mod.application_wsgi import transfer
 from whatap.util.date_util import DateUtil
 from whatap.trace.trace_context_manager import TraceContextManager
 
@@ -13,8 +13,6 @@ def instrument_httplib(module):
             if not ctx or ctx.active_httpc_hash:
                 return fn(*args, **kwargs)
     
-            inter_tx_trace_auto_on(ctx)
-            
             start_time = DateUtil.nowSystem()
             ctx.start_time = start_time
             ctx.httpc_url = args[1]
